@@ -447,57 +447,3 @@ test_that("if factorise = FALSE comorbidity does not return factors", {
   expect_s3_class(cs$windex_ahrq, "factor")
   expect_s3_class(cs$windex_vw, "factor")
 })
-
-test_that("parallel computing works (specifying the number of clusters)", {
-  x <- data.frame(
-    id = sample(1:50, size = 10 * 50, replace = TRUE),
-    code = sample_diag(10 * 50),
-    stringsAsFactors = FALSE
-  )
-  cs1 <- comorbidity(x = x, id = "id", code = "code", score = "charlson", assign0 = FALSE, parallel = TRUE, mc.cores = 1)
-  cs2 <- comorbidity(x = x, id = "id", code = "code", score = "charlson", assign0 = FALSE, parallel = TRUE, mc.cores = 2)
-  cs3 <- comorbidity(x = x, id = "id", code = "code", score = "elixhauser", assign0 = FALSE, parallel = TRUE, mc.cores = 1)
-  cs4 <- comorbidity(x = x, id = "id", code = "code", score = "elixhauser", assign0 = FALSE, parallel = TRUE, mc.cores = 2)
-  expect_equal(nrow(cs1), 50)
-  expect_equal(nrow(cs2), 50)
-  expect_equal(nrow(cs3), 50)
-  expect_equal(nrow(cs4), 50)
-  x <- data.frame(
-    id = sample(1:50, size = 10 * 50, replace = TRUE),
-    code = sample_diag(10 * 50, version = "ICD9_2015"),
-    stringsAsFactors = FALSE
-  )
-  cs1 <- comorbidity(x = x, id = "id", code = "code", score = "charlson", assign0 = FALSE, parallel = TRUE, mc.cores = 1)
-  cs2 <- comorbidity(x = x, id = "id", code = "code", score = "charlson", assign0 = FALSE, parallel = TRUE, mc.cores = 2)
-  cs3 <- comorbidity(x = x, id = "id", code = "code", score = "elixhauser", assign0 = FALSE, parallel = TRUE, mc.cores = 1)
-  cs4 <- comorbidity(x = x, id = "id", code = "code", score = "elixhauser", assign0 = FALSE, parallel = TRUE, mc.cores = 2)
-  expect_equal(nrow(cs1), 50)
-  expect_equal(nrow(cs2), 50)
-  expect_equal(nrow(cs3), 50)
-  expect_equal(nrow(cs4), 50)
-})
-
-test_that("running computations in parallel vs serial returns the same results", {
-  x <- data.frame(
-    id = sample(1:50, size = 10 * 50, replace = TRUE),
-    code = sample_diag(10 * 50),
-    stringsAsFactors = FALSE
-  )
-  cs_serial <- comorbidity(x = x, id = "id", code = "code", score = "charlson", assign0 = FALSE, parallel = FALSE)
-  cs_parallel <- comorbidity(x = x, id = "id", code = "code", score = "charlson", assign0 = FALSE, parallel = TRUE, mc.cores = 2)
-  expect_equal(cs_serial, cs_parallel)
-  cs_serial <- comorbidity(x = x, id = "id", code = "code", score = "elixhauser", assign0 = FALSE, parallel = FALSE)
-  cs_parallel <- comorbidity(x = x, id = "id", code = "code", score = "elixhauser", assign0 = FALSE, parallel = TRUE, mc.cores = 2)
-  expect_equal(cs_serial, cs_parallel)
-  x <- data.frame(
-    id = sample(1:50, size = 10 * 50, replace = TRUE),
-    code = sample_diag(10 * 50, version = "ICD9_2015"),
-    stringsAsFactors = FALSE
-  )
-  cs_serial <- comorbidity(x = x, id = "id", code = "code", score = "charlson", assign0 = FALSE, parallel = FALSE)
-  cs_parallel <- comorbidity(x = x, id = "id", code = "code", score = "charlson", assign0 = FALSE, parallel = TRUE, mc.cores = 2)
-  expect_equal(cs_serial, cs_parallel)
-  cs_serial <- comorbidity(x = x, id = "id", code = "code", score = "elixhauser", assign0 = FALSE, parallel = FALSE)
-  cs_parallel <- comorbidity(x = x, id = "id", code = "code", score = "elixhauser", assign0 = FALSE, parallel = TRUE, mc.cores = 2)
-  expect_equal(cs_serial, cs_parallel)
-})
